package com.usky.fire.controller.web;


import com.usky.common.core.bean.ApiResult;
import com.usky.common.core.bean.CommonPage;
import com.usky.common.log.annotation.Log;
import com.usky.common.log.enums.BusinessType;
import com.usky.fire.domain.AlarmFire;
import com.usky.fire.service.vo.InspectDetailVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.usky.fire.service.DemInspectListService;

import org.springframework.stereotype.Controller;

import java.util.Map;

/**
 * <p>
 * 督察单 前端控制器
 * </p>
 *
 * @author ZYJ
 * @since 2022-12-29
 */
@Controller
@RequestMapping("/demInspect")
public class DemInspectListController {
    @Autowired
    private DemInspectListService demInspectListService;

    /**
     * 事件管理-电子督察单-列表查询
     *
     * @param inspectCode    督察单编号
     * @param companyName    单位名称
     * @param deviceCode     设备编号
     * @param handlingStatus 处置状态（1、已处置 2、待处置 3、督查超时）
     * @param pageNum        当前页
     * @param pageSize       每页条数
     * @return
     */
    @GetMapping("demInspectList")
    public ApiResult<CommonPage<InspectDetailVO>> demInspectList(@RequestParam(value = "inspectCode", required = false) String inspectCode,
                                                             @RequestParam(value = "companyName", required = false) String companyName,
                                                             @RequestParam(value = "deviceCode", required = false) String deviceCode,
                                                             @RequestParam(value = "handlingStatus", required = false) Integer handlingStatus,
                                                             @RequestParam(value = "pageNum", required = false, defaultValue = "1") Integer pageNum,
                                                             @RequestParam(value = "pageSize", required = false, defaultValue = "10") Integer pageSize) {
        return ApiResult.success(demInspectListService.demInspectList(inspectCode, companyName, deviceCode, handlingStatus, pageNum, pageSize));
    }


    /**
     * 事件管理-火警告警处置/隐患报警处理-火灾报警处置/故障告警处置-左侧数据统计
     *
     * @param alarmType 告警类型（2 火警、4 故障、16 监管等）
     * @return
     */
    @GetMapping("fireStatistics")
    public ApiResult<Map<String, Object>> fireStatistics(@RequestParam(value = "companyName", required = false) String companyName,
                                                         @RequestParam(value = "alarmType", required = false) String alarmType,
                                                         @RequestParam(value = "startDate", required = false) String startDate,
                                                         @RequestParam(value = "endDate", required = false) String endDate) {
        return ApiResult.success(alarmFireService.fireStatistics(companyName, alarmType, startDate, endDate));
    }


    /**
     * 事件管理-火警告警处置/隐患报警处理-火灾报警处置/故障告警处置-数据统计图
     *
     * @param alarmType 告警类型（2 火警、4 故障、16 监管、100火警隐患等）
     * @param startDate 开始时间  格式：yyyy-MM-dd HH:mm:ss
     * @param endDate   结束时间  格式：yyyy-MM-dd HH:mm:ss
     * @return
     */
    @GetMapping("fireStatisticalChart")
    public ApiResult<Map<String, Object>> fireStatisticalChart(@RequestParam(value = "alarmType", required = false) String alarmType,
                                                               @RequestParam(value = "startDate", required = false) String startDate,
                                                               @RequestParam(value = "endDate", required = false) String endDate) {
        return ApiResult.success(alarmFireService.fireStatisticalChart(alarmType, startDate, endDate));
    }


    /**
     * 事件管理-火警告警处置/隐患报警处理-火灾报警处置/故障告警处置-告警处理
     *
     * @param alarmFire
     * @return
     */
    @Log(title = "告警处理", businessType = BusinessType.UPDATE)
    @PutMapping("updateAlarmFire")
    public ApiResult<Void> updateAlarmFire(@RequestBody AlarmFire alarmFire) {
        alarmFireService.updateAlarmFire(alarmFire);
        return ApiResult.success();
    }
}

